@@ -12,4 +12,4 @@ def Fibonacci(n):
     return sequenceList[n-1]
 
 
-Fibonacci()
\ No newline at end of file
+Fibonacci(n)
\ No newline at end of file
